5a9c106607b38401620354b237667b53332017ea
braney
  Thu Feb 21 11:04:39 2013 -0800
change trackHubRemoveHubName to trackHubSkipName (per code review #10237)
diff --git src/hg/inc/trackHub.h src/hg/inc/trackHub.h
index c9d8892..2f3d609 100644
--- src/hg/inc/trackHub.h
+++ src/hg/inc/trackHub.h
@@ -132,22 +132,22 @@
 /* get a list of dbDb structures for all the tracks in this clade/hub */
 
 struct slPair *trackHubGetHubLabels();
 /* get a list of labels describing the loaded assembly data hubs */
 
 char *trackHubAssemblyClade(char *genome);
 /* return the clade/hub_name that contains this genome */
 
 void trackHubFixName(char *name);
 /* change all characters other than alphanumeric, dash, and underbar
  * to underbar */
 
 struct grp *trackHubLoadGroups(char *database);
 /* load the grp structures for this track hub database */
 
-char *trackHubRemoveHubName(char *name);
-/* remove the hub_#_ prefix from a hub name */
+char *trackHubSkipHubName(char *name);
+/* skip the hub_#_ prefix in a hub name */
 
 struct dbDb *trackHubDbDbFromAssemblyDb(char *database);
 /* return a dbDb structure for just this database */
 #endif /* TRACKHUB_H */